@@ -16,7 +16,7 @@ CHUNK_SIZE = 1024*1024*2 # 2 MB
 def video_key(video):
     return (
         int(video.videoBitrate.text),
-        video.find("facets") is not None and max([f.text == "progressive" for f in video.facets.facet])
+        video.find("facets") is not None and any((f.text == "progressive" for f in video.facets.facet))
     )
 
 def get_id(url):
